@@ -92,11 +92,13 @@ class socket:
         """
         self.send(data)
 
-    def readline(self):
-        """Attempt to return as many bytes as we can up to but not including '\r\n'"""
+    def readline(self, eol=b"\r\n"):
+        """Attempt to return as many bytes as we can up to but not including
+        end-of-line character (default is '\\r\\n')"""
+
         # print("Socket readline")
         stamp = time.monotonic()
-        while b"\r\n" not in self._buffer:
+        while eol not in self._buffer:
             # there's no line already in there, read some more
             avail = self.available()
             if avail:
@@ -104,7 +106,7 @@ class socket:
             elif self._timeout > 0 and time.monotonic() - stamp > self._timeout:
                 self.close()  # Make sure to close socket so that we don't exhaust sockets.
                 raise RuntimeError("Didn't receive full response, failing out")
-        firstline, self._buffer = self._buffer.split(b"\r\n", 1)
+        firstline, self._buffer = self._buffer.split(eol, 1)
         gc.collect()
         return firstline
 
@@ -159,6 +161,36 @@ class socket:
         gc.collect()
         return ret
 
+    def recv_into(self, buffer):
+        """Read some bytes from the connected remote address into a given buffer
+
+        :param bytearray buffer: The buffer to read into
+        """
+
+        stamp = time.monotonic()
+        to_read = len(buffer)
+        received = []
+        while to_read > 0:
+            # print("Bytes to read:", to_read)
+            avail = self.available()
+            if avail:
+                stamp = time.monotonic()
+                recv = _the_interface.socket_read(self._socknum, min(to_read, avail))
+                # received.append(recv)
+                start = len(buffer) - to_read
+                to_read -= len(recv)
+                end = len(buffer) - to_read
+                buffer[start:end] = bytearray(recv)
+                gc.collect()
+            elif received:
+                # We've received some bytes but no more are available. So return
+                # what we have.
+                break
+            if self._timeout > 0 and time.monotonic() - stamp > self._timeout:
+                break
+        gc.collect()
+        return len(buffer) - to_read
+
     def read(self, size=0):
         """Read up to 'size' bytes from the socket, this may be buffered internally!
         If 'size' isnt specified, return everything in the buffer.
